import itertools
import unittest
import time

import sh

import zdb

import zsearch_definitions.query
import zsearch_definitions.admin


class ZDBTestCase(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        cls.c = zdb.get_zdb_test_config()

    def setUp(self):
        pkill = sh.Command("pkill")
        try:
            pkill("-9", "zdb")
        except sh.ErrorReturnCode:
            pass
        sh.rm("-rf", sh.glob("/tmp/zdb/*"))
        self.zdb_handle = self.c.zdb(_bg=True, _err="zdb_stderr.txt")
        time.sleep(1)

        self.query_grpc = zsearch_definitions.query.QueryService()
        self.admin_grpc = zsearch_definitions.admin.AdminService()

    def tearDown(self):
        if self.zdb_handle is not None:
            self.zdb_handle.terminate()

    def assertTagsEqual(self, a, b):
        self.assertEqual(len(a), len(b))
        for atag, btag in itertools.izip(a, b):
            self.assertEqual(atag, btag)

    def assertMetadatumEqual(self, a, b):
        self.assertEqual(a.key, b.key)
        self.assertEqual(a.value, b.value)

    def assertMetadataEqual(self, a, b):
        self.assertEqual(len(a), len(b))
        for am, bm in itertools.izip(a, b):
            self.assertMetadatumEqual(am, bm)

    def assertProtocolAtomEqual(self, a, b):
        # Check data
        self.assertEqual(a.data, b.data)

        # Check tags
        if a.tags is None:
            self.assertIsNone(b.tags)
        else:
            self.assertIsNotNone(b.tags)
            self.assertTagsEqual(a.tags, b.tags)

        # Check metadata
        if a.metadata is None:
            self.assertIsNone(b.metadata)
        else:
            self.assertIsNotNone(b.metadata)
            self.assertMetadataEqual(a.metadata, b.metadata)

    def assertRecordEqual(self, a, b,
                          check_scan_id=True, check_timestamp=True,
                          check_first_seen_at=True, check_last_seen_at=True):
        self.assertEqual(a.ip, b.ip)
        self.assertEqual(a.port, b.port)
        self.assertEqual(a.protocol, b.protocol)
        self.assertEqual(a.subprotocol, b.subprotocol)
        self.assertEqual(a.domain, b.domain)
        if check_timestamp:
            self.assertEqual(a.timestamp, b.timestamp)
        if check_scan_id:
            self.assertEqual(a.scanid, b.scanid)
        self.assertEqual(a.sha256fp, b.sha256fp)
        if check_first_seen_at:
            self.assertEqual(a.first_seen_at_scan_id, b.first_seen_at_scan_id)
        if check_last_seen_at:
            self.assertEqual(a.last_seen_at_scan_id, b.last_seen_at_scan_id)
        self.assertEqual(a.HasField("atom"), b.HasField("atom"))
        if a.HasField("atom"):
            self.assertProtocolAtomEqual(a.atom, b.atom)
        else:
            # Not yet implemented
            self.fail()

    def assertDeltaMatchesRecord(self, delta, record):
        self.assertEqual(delta.ip, record.ip)
        self.assertEqual(delta.protocol, record.protocol)
        self.assertEqual(delta.port, record.port)
        self.assertEqual(delta.subprotocol, record.subprotocol)
        self.assertEqual(delta.domain, record.domain)
        record_oneof = record.WhichOneof("data_oneof")
        if record_oneof == "atom":
            self.assertTrue(delta.HasField("atom"))
            self.assertProtocolAtomEqual(delta.atom, record.atom)
        else:
            # unimplemented
            self.fail()


    def assertDeltaHasMergedTagsAndMetadata(self, delta, records):
        delta_metadata = {m.key: m.value for m in delta.metadata}
        delta_tags = set(delta.tags)
        merged_tags = set()
        merged_metadata = dict()
        for record in records:
            atom = record.atom
            self.assertIsNotNone(atom)
            metadata = {m.key: m.value for m in atom.metadata}
            merged_tags |= set(atom.tags)
            merged_metadata.update(metadata)
        self.assertEqual(merged_tags, delta_tags)
        self.assertEqual(merged_metadata, delta_metadata)



import sys
import os.path
import base64
import argparse
import datetime
import time
import json
import hashlib
import struct
import socket

from zsearch_definitions import search_pb2
from zsearch_definitions import protocols_pb2
from zsearch_definitions import rpc_pb2
from zsearch_definitions import common_pb2
from zsearch_definitions import anonstore_pb2
from zsearch_definitions import hoststore_pb2


class QueryService(object):

    TIMEOUT = 3 # second
    HOST = "localhost"
    PORT = 9090

    HQ_SUCCESS = rpc_pb2.HostQueryResponse.ResponseStatus.Value("SUCCESS")
    HQ_RESERVED= rpc_pb2.HostQueryResponse.ResponseStatus.Value("RESERVED")
    HQ_NO_RECORD = rpc_pb2.HostQueryResponse.ResponseStatus.Value("NO_RECORD")
    HQ_ERROR = rpc_pb2.HostQueryResponse.ResponseStatus.Value("ERROR")

    AQ_SUCCESS = rpc_pb2.AnonymousQueryResponse.ResponseStatus.Value("SUCCESS")
    AQ_RESERVED= rpc_pb2.AnonymousQueryResponse.ResponseStatus.Value("RESERVED")
    AQ_NO_RECORD = rpc_pb2.AnonymousQueryResponse.ResponseStatus.Value("NO_RECORD")
    AQ_ERROR = rpc_pb2.AnonymousQueryResponse.ResponseStatus.Value("ERROR")

    @staticmethod
    def _port_to_pb(port):
        port_bytes = struct.pack("!H", port)
        (port_net, ) = struct.unpack("H", port_bytes)
        return port_net

    @staticmethod
    def _ip_to_pb(ip):
        ip_packed = socket.inet_aton(ip)
        #ip_bytes = struct.pack("!I", ip_packed)
        (ip_net, ) = struct.unpack("I", ip_packed)
        return ip_net

    @staticmethod
    def _get_atom_fp(atom):
        a = atom.SerializeToString()
        m = hashlib.sha256()
        m.update(a)
        return m.digest()

    def __init__(self, host=None, port=None):
        port = port or self.PORT
        host = host or self.HOST
        self._service = search_pb2.early_adopter_create_QueryService_stub(host,
                port).__enter__()

    @property
    def service(self):
        return self._service

    def get_certificate(self, sha256_fp):
        aq = rpc_pb2.AnonymousQuery(
                sha256fp=b64decode(sha256_fp))
        res = self._service.GetCertificate(aq)
        assert(resp.status != self.AQ_RESERVED)
        if resp.status == self.AQ_ERROR:
            raise Exception("Request failed: %s" % resp.error)
        elif resp.status == self.AQ_NO_RECORD:
            return None
        else: # (SUCCESS)
            return resp.certificate


    def put_certificate(self, raw, parsed):
        sha256_fp = base64.b64decode(parsed["fingerprint_sha256"])
        sha1_fp = base64.b64decode(parsed["fingerprint_sha1"])
        c = anonstore_pb2.Certificate(
                sha1fp=sha1_fp,
                sha256fp=sha256_fp,
                raw=base64.b64decode(raw),
                parsed=json.dumps(parsed)
            )
        ar = anonstore_pb2.AnonymousRecord(
                sha256fp=sha256_fp,
                timestamp=self._get_int_timestamp(),
                exported=False,
                certificate=c)
        return self._service.UpsertCertificate(ar, self.TIMEOUT)


    def _get_host_record(self, meth, ip, domain, port, proto, subproto):
        ip = self._ip_to_pb(ip) if ip else None
        port = self._port_to_pb(port)
        proto = protocols_pb2.Protocol.Value(proto)
        subproto = protocols_pb2.Subprotocol.Value(subproto)
        host_query = rpc_pb2.HostQuery(
                        ip=ip,
                        domain=domain,
                        port=port,
                        proto=proto,
                        subproto=subproto
                     )
        resp = meth(host_query, self.TIMEOUT)
        assert(resp.status != self.HQ_RESERVED)
        if resp.status == self.HQ_ERROR:
            raise Exception("Request failed: %s" % resp.error)
        elif resp.status == self.HQ_NO_RECORD:
            return None
        else: # (SUCCESS)
            return resp.record

    def get_host_ipv4_record(self, ip, port, proto, subproto):
        return self._get_host_record(self._service.GetHostIPv4Record,
            ip, None, port, proto, subproto)

    def get_host_domain_record(self, domain, port, proto, subproto):
        return self._get_host_record(self._service.GetHostDomainRecord,
            None, domain, port, proto, subproto)

    @staticmethod
    def _get_int_timestamp():
        return int(time.mktime(datetime.datetime.now().timetuple()))

    def _make_atom(self, data, tags, metadata):
        metadatums = []
        for k, v in (metadata or {}).items():
            m = common_pb2.Metadatum(key=k, value=v)
            metadatums.append(m)
        atom = hoststore_pb2.ProtocolAtom(metadata=metadatums,
                tags=(tags or []), data=data)
        return atom

    def put_host_ipv4_record(self, ip, port, proto, subproto,
            data, tags=None, metadata=None):
        atom = self._make_atom(data, tags, metadata)
        fp = self._get_atom_fp(atom)
        record = hoststore_pb2.Record(
                    ip=self._ip_to_pb(ip),
                    port=self._port_to_pb(port),
                    protocol=protocols_pb2.Protocol.Value(proto),
                    subprotocol=protocols_pb2.Subprotocol.Value(subproto),
                    timestamp=self._get_int_timestamp(),
                    atom=atom,
                    sha256fp=fp,
                 )
        return self._service.PutHostIPv4Record(record, self.TIMEOUT)

    def put_host_domain_record(self, domain, ip, port, proto, subproto,
            data, tags=None, metadata=None):
        atom = self._make_atom(data, tags, metadata)
        fp = self._get_atom_fp(atom)
        record = hoststore_pb2.Record(
                    domain=domain,
                    ip=self._ip_to_pb(ip),
                    port=self._port_to_pb(port),
                    protocol=protocols_pb2.Protocol.Value(proto),
                    subprotocol=protocols_pb2.Subprotocol.Value(subproto),
                    timestamp=self._get_int_timestamp(),
                    atom=atom
                 )
        return self._service.PutHostDomainRecord(record, self.TIMEOUT)

    def delete_host_ipv4_record(self, ip, port, proto, subproto):
        ip = self._ip_to_pb(ip)
        port = self._port_to_pb(port)
        proto = protocols_pb2.Protocol.Value(proto)
        subproto = protocols_pb2.Subprotocol.Value(subproto)
        host_query = rpc_pb2.HostQuery(
                        ip=ip,
                        port=port,
                        proto=proto,
                        subproto=subproto
                     )
        return self._service.DelHostIPv4Record(host_query, self.TIMEOUT)

    def delete_host_domain_record(self, domain, port, proto, subproto):
        port = self._port_to_pb(port)
        proto = protocols_pb2.Protocol.Value(proto)
        subproto = protocols_pb2.Subprotocol.Value(subproto)
        host_query = rpc_pb2.HostQuery(
                        domain=domain,
                        port=port,
                        proto=proto,
                        subproto=subproto
                     )
        return self._service.DelHostDomainRecord(host_query, self.TIMEOUT)

    def get_host_ipv4_userdata(self, ip):
        raise Exception("not implemented.")

    def put_host_ipv4_userdata(self, ip, userdata):
        raise Exception("not implemented.")

    def iter_host_records(self, meth):
        resp = meth(rpc_pb2.HostQuery(), self.TIMEOUT)
        assert(resp.status != self.HQ_RESERVED)
        if resp.status == self.HQ_ERROR:
            raise Exception("Request failed: %s" % resp.error)
        for r in resp.records:
            yield r

    def iter_ipv4_records(self):
        for record in self.iter_host_records(self._service.GetAllIPv4Records):
            yield record

    def iter_domain_records(self):
        for record in self.iter_host_records(self._service.GetAllDomainRecords):
            yield record

    def __del__(self):
        if self._service:
            self._service.__exit__(None, None, None)



import zdb
import itertools
from zsearch_definitions import hoststore_pb2
import time

import testcase


# pylint: disable=no-member
class RedisTest(testcase.ZDBTestCase):

    IN_QUEUE = "ipv4"
    DELTA_QUEUE = "ipv4_deltas"

    def setUp(self):
        super(RedisTest, self).setUp()
        self.rctx = self.c.redis
        self.rctx.delete(RedisTest.IN_QUEUE)
        self.rctx.delete(RedisTest.DELTA_QUEUE)

    def test_add_ten_ipv4(self):
        start_ip = 0x01020304
        stop_ip = start_ip + 10
        inc = list(zdb.iter_ipv4_record(start_ip, 443, 3, 2, ip_stop=stop_ip))
        self.assertEqual(len(inc), 10)
        deltas = list()
        for record in inc:
            self.rctx.rpush(RedisTest.IN_QUEUE, record.SerializeToString())
            out = self.rctx.blpop(RedisTest.DELTA_QUEUE, timeout=3)
            self.assertIsNotNone(out)
            self.assertEqual(len(out), 2)
            delta = hoststore_pb2.Delta()
            delta.ParseFromString(out[1])
            deltas.append(delta)
        queue_len = self.rctx.llen(RedisTest.IN_QUEUE)
        self.assertEqual(queue_len, 0)
        for record, delta in itertools.izip(inc, deltas):
            self.assertEqual(delta.delta_type, hoststore_pb2.Delta.DT_UPDATE)
            self.assertEqual(delta.delta_scope, hoststore_pb2.Delta.SCOPE_HOST)
            self.assertDeltaMatchesRecord(delta, record)
        for record in inc:
            self.rctx.rpush(RedisTest.IN_QUEUE, record.SerializeToString())
        # zdb has a 3 second poll
        time.sleep(3)
        delta_len = self.rctx.llen(RedisTest.DELTA_QUEUE)
        self.assertEqual(delta_len, 0)
        



import json
import test.testcase
import time

class CertificateTests(test.testcase.ZDBTestCase):

    def add_mock_certificates(self):
        certs = json.loads(open("test/certificates.json").read())
        for cert in certs:
            self.query_grpc.put_certificate(cert["raw"], cert["parsed"])

    def test_certificate_dump(self):
        time.sleep(3)
        self.add_mock_certificates()
        self.admin_grpc.dump_certificates(path="certificates.json", incremental=False)


# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zsearch_definitions/search.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zsearch_definitions import protocols_pb2 as zsearch__definitions_dot_protocols__pb2
from zsearch_definitions import anonstore_pb2 as zsearch__definitions_dot_anonstore__pb2
from zsearch_definitions import hoststore_pb2 as zsearch__definitions_dot_hoststore__pb2
from zsearch_definitions import rpc_pb2 as zsearch__definitions_dot_rpc__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='zsearch_definitions/search.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n zsearch_definitions/search.proto\x12\x07zsearch\x1a#zsearch_definitions/protocols.proto\x1a#zsearch_definitions/anonstore.proto\x1a#zsearch_definitions/hoststore.proto\x1a\x1dzsearch_definitions/rpc.proto2\x9f\x05\n\x0c\x41\x64minService\x12\x35\n\x08Shutdown\x12\x10.zsearch.Command\x1a\x15.zsearch.CommandReply\"\x00\x12\x33\n\x06Status\x12\x10.zsearch.Command\x1a\x15.zsearch.CommandReply\"\x00\x12\x37\n\nStatistics\x12\x10.zsearch.Command\x1a\x15.zsearch.CommandReply\"\x00\x12\x36\n\tPruneIPv4\x12\x10.zsearch.Command\x1a\x15.zsearch.CommandReply\"\x00\x12\x38\n\x0bPruneDomain\x12\x10.zsearch.Command\x1a\x15.zsearch.CommandReply\"\x00\x12\x39\n\x0cUpdateASData\x12\x10.zsearch.Command\x1a\x15.zsearch.CommandReply\"\x00\x12?\n\x12UpdateLocationData\x12\x10.zsearch.Command\x1a\x15.zsearch.CommandReply\"\x00\x12;\n\x0e\x44umpIPv4ToJSON\x12\x10.zsearch.Command\x1a\x15.zsearch.CommandReply\"\x00\x12=\n\x10\x44umpDomainToJSON\x12\x10.zsearch.Command\x1a\x15.zsearch.CommandReply\"\x00\x12\x43\n\x16\x44umpCertificatesToJSON\x12\x10.zsearch.Command\x1a\x15.zsearch.CommandReply\"\x00\x12;\n\x0e\x44umpKeysToJSON\x12\x10.zsearch.Command\x1a\x15.zsearch.CommandReply\"\x00\x32\xc8\t\n\x0cQueryService\x12\x45\n\x11GetHostIPv4Record\x12\x12.zsearch.HostQuery\x1a\x1a.zsearch.HostQueryResponse\"\x00\x12\x36\n\x11PutHostIPv4Record\x12\x0f.zsearch.Record\x1a\x0e.zsearch.Delta\"\x00\x12\x39\n\x11\x44\x65lHostIPv4Record\x12\x12.zsearch.HostQuery\x1a\x0e.zsearch.Delta\"\x00\x12\x45\n\x11GetAllIPv4Records\x12\x12.zsearch.HostQuery\x1a\x1a.zsearch.HostQueryResponse\"\x00\x12G\n\x13GetHostDomainRecord\x12\x12.zsearch.HostQuery\x1a\x1a.zsearch.HostQueryResponse\"\x00\x12\x38\n\x13PutHostDomainRecord\x12\x0f.zsearch.Record\x1a\x0e.zsearch.Delta\"\x00\x12;\n\x13\x44\x65lHostDomainRecord\x12\x12.zsearch.HostQuery\x1a\x0e.zsearch.Delta\"\x00\x12G\n\x13GetAllDomainRecords\x12\x12.zsearch.HostQuery\x1a\x1a.zsearch.HostQueryResponse\"\x00\x12L\n\x0eGetCertificate\x12\x17.zsearch.AnonymousQuery\x1a\x1f.zsearch.AnonymousQueryResponse\"\x00\x12H\n\x11UpsertCertificate\x12\x18.zsearch.AnonymousRecord\x1a\x17.zsearch.AnonymousDelta\"\x00\x12Q\n\x13GetCryptographicKey\x12\x17.zsearch.AnonymousQuery\x1a\x1f.zsearch.AnonymousQueryResponse\"\x00\x12M\n\x16UpsertCryptographicKey\x12\x18.zsearch.AnonymousRecord\x1a\x17.zsearch.AnonymousDelta\"\x00\x12@\n\x11GetPublicLocation\x12\x12.zsearch.HostQuery\x1a\x15.zsearch.LocationAtom\"\x00\x12\x44\n\x15GetRestrictedLocation\x12\x12.zsearch.HostQuery\x1a\x15.zsearch.LocationAtom\"\x00\x12\x31\n\x08GetWHOIS\x12\x12.zsearch.HostQuery\x1a\x0f.zsearch.Record\"\x00\x12\x38\n\x0fGetUserMetadata\x12\x12.zsearch.HostQuery\x1a\x0f.zsearch.Record\"\x00\x12;\n\x0fPutUserMetadata\x12\x0f.zsearch.Record\x1a\x15.zsearch.CommandReply\"\x00\x12\x42\n\x0cGetRootStore\x12\x17.zsearch.RootStoreQuery\x1a\x17.zsearch.RootStoreReply\"\x00\x62\x06proto3')
  ,
  dependencies=[zsearch__definitions_dot_protocols__pb2.DESCRIPTOR,zsearch__definitions_dot_anonstore__pb2.DESCRIPTOR,zsearch__definitions_dot_hoststore__pb2.DESCRIPTOR,zsearch__definitions_dot_rpc__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)





import abc
from grpc.early_adopter import implementations
from grpc.framework.alpha import utilities
class EarlyAdopterAdminServiceServicer(object):
  """<fill me in later!>"""
  __metaclass__ = abc.ABCMeta
  @abc.abstractmethod
  def Shutdown(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def Status(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def Statistics(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def PruneIPv4(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def PruneDomain(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def UpdateASData(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def UpdateLocationData(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def DumpIPv4ToJSON(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def DumpDomainToJSON(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def DumpCertificatesToJSON(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def DumpKeysToJSON(self, request, context):
    raise NotImplementedError()
class EarlyAdopterAdminServiceServer(object):
  """<fill me in later!>"""
  __metaclass__ = abc.ABCMeta
  @abc.abstractmethod
  def start(self):
    raise NotImplementedError()
  @abc.abstractmethod
  def stop(self):
    raise NotImplementedError()
class EarlyAdopterAdminServiceStub(object):
  """<fill me in later!>"""
  __metaclass__ = abc.ABCMeta
  @abc.abstractmethod
  def Shutdown(self, request):
    raise NotImplementedError()
  Shutdown.async = None
  @abc.abstractmethod
  def Status(self, request):
    raise NotImplementedError()
  Status.async = None
  @abc.abstractmethod
  def Statistics(self, request):
    raise NotImplementedError()
  Statistics.async = None
  @abc.abstractmethod
  def PruneIPv4(self, request):
    raise NotImplementedError()
  PruneIPv4.async = None
  @abc.abstractmethod
  def PruneDomain(self, request):
    raise NotImplementedError()
  PruneDomain.async = None
  @abc.abstractmethod
  def UpdateASData(self, request):
    raise NotImplementedError()
  UpdateASData.async = None
  @abc.abstractmethod
  def UpdateLocationData(self, request):
    raise NotImplementedError()
  UpdateLocationData.async = None
  @abc.abstractmethod
  def DumpIPv4ToJSON(self, request):
    raise NotImplementedError()
  DumpIPv4ToJSON.async = None
  @abc.abstractmethod
  def DumpDomainToJSON(self, request):
    raise NotImplementedError()
  DumpDomainToJSON.async = None
  @abc.abstractmethod
  def DumpCertificatesToJSON(self, request):
    raise NotImplementedError()
  DumpCertificatesToJSON.async = None
  @abc.abstractmethod
  def DumpKeysToJSON(self, request):
    raise NotImplementedError()
  DumpKeysToJSON.async = None
def early_adopter_create_AdminService_server(servicer, port, private_key=None, certificate_chain=None):
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  method_service_descriptions = {
    "DumpCertificatesToJSON": utilities.unary_unary_service_description(
      servicer.DumpCertificatesToJSON,
      zsearch_definitions.rpc_pb2.Command.FromString,
      zsearch_definitions.rpc_pb2.CommandReply.SerializeToString,
    ),
    "DumpDomainToJSON": utilities.unary_unary_service_description(
      servicer.DumpDomainToJSON,
      zsearch_definitions.rpc_pb2.Command.FromString,
      zsearch_definitions.rpc_pb2.CommandReply.SerializeToString,
    ),
    "DumpIPv4ToJSON": utilities.unary_unary_service_description(
      servicer.DumpIPv4ToJSON,
      zsearch_definitions.rpc_pb2.Command.FromString,
      zsearch_definitions.rpc_pb2.CommandReply.SerializeToString,
    ),
    "DumpKeysToJSON": utilities.unary_unary_service_description(
      servicer.DumpKeysToJSON,
      zsearch_definitions.rpc_pb2.Command.FromString,
      zsearch_definitions.rpc_pb2.CommandReply.SerializeToString,
    ),
    "PruneDomain": utilities.unary_unary_service_description(
      servicer.PruneDomain,
      zsearch_definitions.rpc_pb2.Command.FromString,
      zsearch_definitions.rpc_pb2.CommandReply.SerializeToString,
    ),
    "PruneIPv4": utilities.unary_unary_service_description(
      servicer.PruneIPv4,
      zsearch_definitions.rpc_pb2.Command.FromString,
      zsearch_definitions.rpc_pb2.CommandReply.SerializeToString,
    ),
    "Shutdown": utilities.unary_unary_service_description(
      servicer.Shutdown,
      zsearch_definitions.rpc_pb2.Command.FromString,
      zsearch_definitions.rpc_pb2.CommandReply.SerializeToString,
    ),
    "Statistics": utilities.unary_unary_service_description(
      servicer.Statistics,
      zsearch_definitions.rpc_pb2.Command.FromString,
      zsearch_definitions.rpc_pb2.CommandReply.SerializeToString,
    ),
    "Status": utilities.unary_unary_service_description(
      servicer.Status,
      zsearch_definitions.rpc_pb2.Command.FromString,
      zsearch_definitions.rpc_pb2.CommandReply.SerializeToString,
    ),
    "UpdateASData": utilities.unary_unary_service_description(
      servicer.UpdateASData,
      zsearch_definitions.rpc_pb2.Command.FromString,
      zsearch_definitions.rpc_pb2.CommandReply.SerializeToString,
    ),
    "UpdateLocationData": utilities.unary_unary_service_description(
      servicer.UpdateLocationData,
      zsearch_definitions.rpc_pb2.Command.FromString,
      zsearch_definitions.rpc_pb2.CommandReply.SerializeToString,
    ),
  }
  return implementations.server("zsearch.AdminService", method_service_descriptions, port, private_key=private_key, certificate_chain=certificate_chain)
def early_adopter_create_AdminService_stub(host, port, metadata_transformer=None, secure=False, root_certificates=None, private_key=None, certificate_chain=None, server_host_override=None):
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  method_invocation_descriptions = {
    "DumpCertificatesToJSON": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.Command.SerializeToString,
      zsearch_definitions.rpc_pb2.CommandReply.FromString,
    ),
    "DumpDomainToJSON": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.Command.SerializeToString,
      zsearch_definitions.rpc_pb2.CommandReply.FromString,
    ),
    "DumpIPv4ToJSON": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.Command.SerializeToString,
      zsearch_definitions.rpc_pb2.CommandReply.FromString,
    ),
    "DumpKeysToJSON": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.Command.SerializeToString,
      zsearch_definitions.rpc_pb2.CommandReply.FromString,
    ),
    "PruneDomain": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.Command.SerializeToString,
      zsearch_definitions.rpc_pb2.CommandReply.FromString,
    ),
    "PruneIPv4": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.Command.SerializeToString,
      zsearch_definitions.rpc_pb2.CommandReply.FromString,
    ),
    "Shutdown": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.Command.SerializeToString,
      zsearch_definitions.rpc_pb2.CommandReply.FromString,
    ),
    "Statistics": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.Command.SerializeToString,
      zsearch_definitions.rpc_pb2.CommandReply.FromString,
    ),
    "Status": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.Command.SerializeToString,
      zsearch_definitions.rpc_pb2.CommandReply.FromString,
    ),
    "UpdateASData": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.Command.SerializeToString,
      zsearch_definitions.rpc_pb2.CommandReply.FromString,
    ),
    "UpdateLocationData": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.Command.SerializeToString,
      zsearch_definitions.rpc_pb2.CommandReply.FromString,
    ),
  }
  return implementations.stub("zsearch.AdminService", method_invocation_descriptions, host, port, metadata_transformer=metadata_transformer, secure=secure, root_certificates=root_certificates, private_key=private_key, certificate_chain=certificate_chain, server_host_override=server_host_override)
class EarlyAdopterQueryServiceServicer(object):
  """<fill me in later!>"""
  __metaclass__ = abc.ABCMeta
  @abc.abstractmethod
  def GetHostIPv4Record(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def PutHostIPv4Record(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def DelHostIPv4Record(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def GetAllIPv4Records(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def GetHostDomainRecord(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def PutHostDomainRecord(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def DelHostDomainRecord(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def GetAllDomainRecords(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def GetCertificate(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def UpsertCertificate(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def GetCryptographicKey(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def UpsertCryptographicKey(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def GetPublicLocation(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def GetRestrictedLocation(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def GetWHOIS(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def GetUserMetadata(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def PutUserMetadata(self, request, context):
    raise NotImplementedError()
  @abc.abstractmethod
  def GetRootStore(self, request, context):
    raise NotImplementedError()
class EarlyAdopterQueryServiceServer(object):
  """<fill me in later!>"""
  __metaclass__ = abc.ABCMeta
  @abc.abstractmethod
  def start(self):
    raise NotImplementedError()
  @abc.abstractmethod
  def stop(self):
    raise NotImplementedError()
class EarlyAdopterQueryServiceStub(object):
  """<fill me in later!>"""
  __metaclass__ = abc.ABCMeta
  @abc.abstractmethod
  def GetHostIPv4Record(self, request):
    raise NotImplementedError()
  GetHostIPv4Record.async = None
  @abc.abstractmethod
  def PutHostIPv4Record(self, request):
    raise NotImplementedError()
  PutHostIPv4Record.async = None
  @abc.abstractmethod
  def DelHostIPv4Record(self, request):
    raise NotImplementedError()
  DelHostIPv4Record.async = None
  @abc.abstractmethod
  def GetAllIPv4Records(self, request):
    raise NotImplementedError()
  GetAllIPv4Records.async = None
  @abc.abstractmethod
  def GetHostDomainRecord(self, request):
    raise NotImplementedError()
  GetHostDomainRecord.async = None
  @abc.abstractmethod
  def PutHostDomainRecord(self, request):
    raise NotImplementedError()
  PutHostDomainRecord.async = None
  @abc.abstractmethod
  def DelHostDomainRecord(self, request):
    raise NotImplementedError()
  DelHostDomainRecord.async = None
  @abc.abstractmethod
  def GetAllDomainRecords(self, request):
    raise NotImplementedError()
  GetAllDomainRecords.async = None
  @abc.abstractmethod
  def GetCertificate(self, request):
    raise NotImplementedError()
  GetCertificate.async = None
  @abc.abstractmethod
  def UpsertCertificate(self, request):
    raise NotImplementedError()
  UpsertCertificate.async = None
  @abc.abstractmethod
  def GetCryptographicKey(self, request):
    raise NotImplementedError()
  GetCryptographicKey.async = None
  @abc.abstractmethod
  def UpsertCryptographicKey(self, request):
    raise NotImplementedError()
  UpsertCryptographicKey.async = None
  @abc.abstractmethod
  def GetPublicLocation(self, request):
    raise NotImplementedError()
  GetPublicLocation.async = None
  @abc.abstractmethod
  def GetRestrictedLocation(self, request):
    raise NotImplementedError()
  GetRestrictedLocation.async = None
  @abc.abstractmethod
  def GetWHOIS(self, request):
    raise NotImplementedError()
  GetWHOIS.async = None
  @abc.abstractmethod
  def GetUserMetadata(self, request):
    raise NotImplementedError()
  GetUserMetadata.async = None
  @abc.abstractmethod
  def PutUserMetadata(self, request):
    raise NotImplementedError()
  PutUserMetadata.async = None
  @abc.abstractmethod
  def GetRootStore(self, request):
    raise NotImplementedError()
  GetRootStore.async = None
def early_adopter_create_QueryService_server(servicer, port, private_key=None, certificate_chain=None):
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.anonstore_pb2
  import zsearch_definitions.anonstore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.anonstore_pb2
  import zsearch_definitions.anonstore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  method_service_descriptions = {
    "DelHostDomainRecord": utilities.unary_unary_service_description(
      servicer.DelHostDomainRecord,
      zsearch_definitions.rpc_pb2.HostQuery.FromString,
      zsearch_definitions.hoststore_pb2.Delta.SerializeToString,
    ),
    "DelHostIPv4Record": utilities.unary_unary_service_description(
      servicer.DelHostIPv4Record,
      zsearch_definitions.rpc_pb2.HostQuery.FromString,
      zsearch_definitions.hoststore_pb2.Delta.SerializeToString,
    ),
    "GetAllDomainRecords": utilities.unary_unary_service_description(
      servicer.GetAllDomainRecords,
      zsearch_definitions.rpc_pb2.HostQuery.FromString,
      zsearch_definitions.rpc_pb2.HostQueryResponse.SerializeToString,
    ),
    "GetAllIPv4Records": utilities.unary_unary_service_description(
      servicer.GetAllIPv4Records,
      zsearch_definitions.rpc_pb2.HostQuery.FromString,
      zsearch_definitions.rpc_pb2.HostQueryResponse.SerializeToString,
    ),
    "GetCertificate": utilities.unary_unary_service_description(
      servicer.GetCertificate,
      zsearch_definitions.rpc_pb2.AnonymousQuery.FromString,
      zsearch_definitions.rpc_pb2.AnonymousQueryResponse.SerializeToString,
    ),
    "GetCryptographicKey": utilities.unary_unary_service_description(
      servicer.GetCryptographicKey,
      zsearch_definitions.rpc_pb2.AnonymousQuery.FromString,
      zsearch_definitions.rpc_pb2.AnonymousQueryResponse.SerializeToString,
    ),
    "GetHostDomainRecord": utilities.unary_unary_service_description(
      servicer.GetHostDomainRecord,
      zsearch_definitions.rpc_pb2.HostQuery.FromString,
      zsearch_definitions.rpc_pb2.HostQueryResponse.SerializeToString,
    ),
    "GetHostIPv4Record": utilities.unary_unary_service_description(
      servicer.GetHostIPv4Record,
      zsearch_definitions.rpc_pb2.HostQuery.FromString,
      zsearch_definitions.rpc_pb2.HostQueryResponse.SerializeToString,
    ),
    "GetPublicLocation": utilities.unary_unary_service_description(
      servicer.GetPublicLocation,
      zsearch_definitions.rpc_pb2.HostQuery.FromString,
      zsearch_definitions.hoststore_pb2.LocationAtom.SerializeToString,
    ),
    "GetRestrictedLocation": utilities.unary_unary_service_description(
      servicer.GetRestrictedLocation,
      zsearch_definitions.rpc_pb2.HostQuery.FromString,
      zsearch_definitions.hoststore_pb2.LocationAtom.SerializeToString,
    ),
    "GetRootStore": utilities.unary_unary_service_description(
      servicer.GetRootStore,
      zsearch_definitions.rpc_pb2.RootStoreQuery.FromString,
      zsearch_definitions.rpc_pb2.RootStoreReply.SerializeToString,
    ),
    "GetUserMetadata": utilities.unary_unary_service_description(
      servicer.GetUserMetadata,
      zsearch_definitions.rpc_pb2.HostQuery.FromString,
      zsearch_definitions.hoststore_pb2.Record.SerializeToString,
    ),
    "GetWHOIS": utilities.unary_unary_service_description(
      servicer.GetWHOIS,
      zsearch_definitions.rpc_pb2.HostQuery.FromString,
      zsearch_definitions.hoststore_pb2.Record.SerializeToString,
    ),
    "PutHostDomainRecord": utilities.unary_unary_service_description(
      servicer.PutHostDomainRecord,
      zsearch_definitions.hoststore_pb2.Record.FromString,
      zsearch_definitions.hoststore_pb2.Delta.SerializeToString,
    ),
    "PutHostIPv4Record": utilities.unary_unary_service_description(
      servicer.PutHostIPv4Record,
      zsearch_definitions.hoststore_pb2.Record.FromString,
      zsearch_definitions.hoststore_pb2.Delta.SerializeToString,
    ),
    "PutUserMetadata": utilities.unary_unary_service_description(
      servicer.PutUserMetadata,
      zsearch_definitions.hoststore_pb2.Record.FromString,
      zsearch_definitions.rpc_pb2.CommandReply.SerializeToString,
    ),
    "UpsertCertificate": utilities.unary_unary_service_description(
      servicer.UpsertCertificate,
      zsearch_definitions.anonstore_pb2.AnonymousRecord.FromString,
      zsearch_definitions.anonstore_pb2.AnonymousDelta.SerializeToString,
    ),
    "UpsertCryptographicKey": utilities.unary_unary_service_description(
      servicer.UpsertCryptographicKey,
      zsearch_definitions.anonstore_pb2.AnonymousRecord.FromString,
      zsearch_definitions.anonstore_pb2.AnonymousDelta.SerializeToString,
    ),
  }
  return implementations.server("zsearch.QueryService", method_service_descriptions, port, private_key=private_key, certificate_chain=certificate_chain)
def early_adopter_create_QueryService_stub(host, port, metadata_transformer=None, secure=False, root_certificates=None, private_key=None, certificate_chain=None, server_host_override=None):
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.anonstore_pb2
  import zsearch_definitions.anonstore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.anonstore_pb2
  import zsearch_definitions.anonstore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.hoststore_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  import zsearch_definitions.rpc_pb2
  method_invocation_descriptions = {
    "DelHostDomainRecord": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.HostQuery.SerializeToString,
      zsearch_definitions.hoststore_pb2.Delta.FromString,
    ),
    "DelHostIPv4Record": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.HostQuery.SerializeToString,
      zsearch_definitions.hoststore_pb2.Delta.FromString,
    ),
    "GetAllDomainRecords": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.HostQuery.SerializeToString,
      zsearch_definitions.rpc_pb2.HostQueryResponse.FromString,
    ),
    "GetAllIPv4Records": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.HostQuery.SerializeToString,
      zsearch_definitions.rpc_pb2.HostQueryResponse.FromString,
    ),
    "GetCertificate": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.AnonymousQuery.SerializeToString,
      zsearch_definitions.rpc_pb2.AnonymousQueryResponse.FromString,
    ),
    "GetCryptographicKey": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.AnonymousQuery.SerializeToString,
      zsearch_definitions.rpc_pb2.AnonymousQueryResponse.FromString,
    ),
    "GetHostDomainRecord": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.HostQuery.SerializeToString,
      zsearch_definitions.rpc_pb2.HostQueryResponse.FromString,
    ),
    "GetHostIPv4Record": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.HostQuery.SerializeToString,
      zsearch_definitions.rpc_pb2.HostQueryResponse.FromString,
    ),
    "GetPublicLocation": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.HostQuery.SerializeToString,
      zsearch_definitions.hoststore_pb2.LocationAtom.FromString,
    ),
    "GetRestrictedLocation": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.HostQuery.SerializeToString,
      zsearch_definitions.hoststore_pb2.LocationAtom.FromString,
    ),
    "GetRootStore": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.RootStoreQuery.SerializeToString,
      zsearch_definitions.rpc_pb2.RootStoreReply.FromString,
    ),
    "GetUserMetadata": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.HostQuery.SerializeToString,
      zsearch_definitions.hoststore_pb2.Record.FromString,
    ),
    "GetWHOIS": utilities.unary_unary_invocation_description(
      zsearch_definitions.rpc_pb2.HostQuery.SerializeToString,
      zsearch_definitions.hoststore_pb2.Record.FromString,
    ),
    "PutHostDomainRecord": utilities.unary_unary_invocation_description(
      zsearch_definitions.hoststore_pb2.Record.SerializeToString,
      zsearch_definitions.hoststore_pb2.Delta.FromString,
    ),
    "PutHostIPv4Record": utilities.unary_unary_invocation_description(
      zsearch_definitions.hoststore_pb2.Record.SerializeToString,
      zsearch_definitions.hoststore_pb2.Delta.FromString,
    ),
    "PutUserMetadata": utilities.unary_unary_invocation_description(
      zsearch_definitions.hoststore_pb2.Record.SerializeToString,
      zsearch_definitions.rpc_pb2.CommandReply.FromString,
    ),
    "UpsertCertificate": utilities.unary_unary_invocation_description(
      zsearch_definitions.anonstore_pb2.AnonymousRecord.SerializeToString,
      zsearch_definitions.anonstore_pb2.AnonymousDelta.FromString,
    ),
    "UpsertCryptographicKey": utilities.unary_unary_invocation_description(
      zsearch_definitions.anonstore_pb2.AnonymousRecord.SerializeToString,
      zsearch_definitions.anonstore_pb2.AnonymousDelta.FromString,
    ),
  }
  return implementations.stub("zsearch.QueryService", method_invocation_descriptions, host, port, metadata_transformer=metadata_transformer, secure=secure, root_certificates=root_certificates, private_key=private_key, certificate_chain=certificate_chain, server_host_override=server_host_override)
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zsearch_definitions/anonstore.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zsearch_definitions import common_pb2 as zsearch__definitions_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='zsearch_definitions/anonstore.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n#zsearch_definitions/anonstore.proto\x12\x07zsearch\x1a zsearch_definitions/common.proto\"\xa7\x01\n\x0b\x43\x65rtificate\x12\x0e\n\x06sha1fp\x18\x01 \x01(\x0c\x12\x10\n\x08sha256fp\x18\x02 \x01(\x0c\x12\x0b\n\x03raw\x18\x03 \x01(\x0c\x12\x0e\n\x06parsed\x18\x04 \x01(\t\x12\x0f\n\x07parents\x18\x05 \x03(\x0c\x12\x14\n\x0cNSSRootStore\x18\x06 \x01(\x08\x12\x1a\n\x12MicrosoftRootStore\x18\x07 \x01(\x08\x12\x16\n\x0e\x41ppleRootStore\x18\x08 \x01(\x08\"N\n\x13RSACryptographicKey\x12\x0f\n\x07modulus\x18\x01 \x01(\x0c\x12\x10\n\x08\x65xponent\x18\x02 \x01(\x0c\x12\t\n\x01p\x18\x03 \x01(\x0c\x12\t\n\x01q\x18\x04 \x01(\x0c\"L\n\x13\x44SACryptographicKey\x12\t\n\x01p\x18\x01 \x01(\x0c\x12\t\n\x01q\x18\x02 \x01(\x0c\x12\t\n\x01g\x18\x03 \x01(\x0c\x12\t\n\x01y\x18\x04 \x01(\x0c\x12\t\n\x01x\x18\x05 \x01(\x0c\"K\n\x13\x45\x43\x43\x43ryptographicKey\x12\r\n\x05\x63urve\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x0c\x12\t\n\x01y\x18\x03 \x01(\x0c\x12\x0f\n\x07private\x18\x04 \x01(\x0c\"\xc8\x02\n\x10\x43ryptographicKey\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.zsearch.CryptographicKey.KeyType\x12+\n\x03rsa\x18\x02 \x01(\x0b\x32\x1c.zsearch.RSACryptographicKeyH\x00\x12+\n\x03\x64sa\x18\x03 \x01(\x0b\x32\x1c.zsearch.DSACryptographicKeyH\x00\x12+\n\x03\x65\x63\x63\x18\x04 \x01(\x0b\x32\x1c.zsearch.ECCCryptographicKeyH\x00\x12\x0e\n\x06\x62roken\x18\x05 \x01(\x08\x12\x0e\n\x06\x63ommon\x18\x06 \x01(\x08\x12\x0e\n\x06\x64\x65\x62ian\x18\x07 \x01(\x08\"?\n\x07KeyType\x12\x0c\n\x08RESERVED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x07\n\x03RSA\x10\x02\x12\x07\n\x03\x44SA\x10\x03\x12\x07\n\x03\x45\x43\x43\x10\x04\x42\x0b\n\tkey_oneof\"\xde\x02\n\x0f\x41nonymousRecord\x12\x10\n\x08sha256fp\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\x07\x12\x0f\n\x07scan_id\x18\x03 \x01(\r\x12\x10\n\x08\x65xported\x18\x04 \x01(\x08\x12\'\n\x08userdata\x18\x05 \x01(\x0b\x32\x15.zsearch.UserdataAtom\x12\x0e\n\x04\x64\x61ta\x18\x06 \x01(\tH\x00\x12\x12\n\x08raw_data\x18\x07 \x01(\x0cH\x00\x12+\n\x0b\x63\x65rtificate\x18\x08 \x01(\x0b\x32\x14.zsearch.CertificateH\x00\x12(\n\x03key\x18\t \x01(\x0b\x32\x19.zsearch.CryptographicKeyH\x00\x12\x1d\n\x02\x61s\x18\n \x01(\x0b\x32\x0f.zsearch.ASAtomH\x00\x12$\n\x08metadata\x18\x0e \x03(\x0b\x32\x12.zsearch.Metadatum\x12\x0c\n\x04tags\x18\x0f \x03(\tB\x0c\n\noneof_data\"\xbe\x02\n\x0e\x41nonymousDelta\x12\x35\n\ndelta_type\x18\x01 \x01(\x0e\x32!.zsearch.AnonymousDelta.DeltaType\x12\x37\n\x0b\x64\x65lta_scope\x18\x02 \x01(\x0e\x32\".zsearch.AnonymousDelta.DeltaScope\x12(\n\x06record\x18\x03 \x01(\x0b\x32\x18.zsearch.AnonymousRecord\":\n\tDeltaType\x12\x0f\n\x0b\x44T_RESERVED\x10\x00\x12\r\n\tDT_UPDATE\x10\x01\x12\r\n\tDT_DELETE\x10\x02\"V\n\nDeltaScope\x12\x12\n\x0eSCOPE_RESERVED\x10\x00\x12\x13\n\x0fSCOPE_NO_CHANGE\x10\x01\x12\r\n\tSCOPE_NEW\x10\x02\x12\x10\n\x0cSCOPE_UPDATE\x10\x03\x62\x06proto3')
  ,
  dependencies=[zsearch__definitions_dot_common__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CRYPTOGRAPHICKEY_KEYTYPE = _descriptor.EnumDescriptor(
  name='KeyType',
  full_name='zsearch.CryptographicKey.KeyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RSA', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DSA', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ECC', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=740,
  serialized_end=803,
)
_sym_db.RegisterEnumDescriptor(_CRYPTOGRAPHICKEY_KEYTYPE)

_ANONYMOUSDELTA_DELTATYPE = _descriptor.EnumDescriptor(
  name='DeltaType',
  full_name='zsearch.AnonymousDelta.DeltaType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DT_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DT_UPDATE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DT_DELETE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1344,
  serialized_end=1402,
)
_sym_db.RegisterEnumDescriptor(_ANONYMOUSDELTA_DELTATYPE)

_ANONYMOUSDELTA_DELTASCOPE = _descriptor.EnumDescriptor(
  name='DeltaScope',
  full_name='zsearch.AnonymousDelta.DeltaScope',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCOPE_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_NO_CHANGE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_NEW', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_UPDATE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1404,
  serialized_end=1490,
)
_sym_db.RegisterEnumDescriptor(_ANONYMOUSDELTA_DELTASCOPE)


_CERTIFICATE = _descriptor.Descriptor(
  name='Certificate',
  full_name='zsearch.Certificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha1fp', full_name='zsearch.Certificate.sha1fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.Certificate.sha256fp', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raw', full_name='zsearch.Certificate.raw', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parsed', full_name='zsearch.Certificate.parsed', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parents', full_name='zsearch.Certificate.parents', index=4,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='NSSRootStore', full_name='zsearch.Certificate.NSSRootStore', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='MicrosoftRootStore', full_name='zsearch.Certificate.MicrosoftRootStore', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='AppleRootStore', full_name='zsearch.Certificate.AppleRootStore', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=250,
)


_RSACRYPTOGRAPHICKEY = _descriptor.Descriptor(
  name='RSACryptographicKey',
  full_name='zsearch.RSACryptographicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modulus', full_name='zsearch.RSACryptographicKey.modulus', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exponent', full_name='zsearch.RSACryptographicKey.exponent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='p', full_name='zsearch.RSACryptographicKey.p', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='q', full_name='zsearch.RSACryptographicKey.q', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=330,
)


_DSACRYPTOGRAPHICKEY = _descriptor.Descriptor(
  name='DSACryptographicKey',
  full_name='zsearch.DSACryptographicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p', full_name='zsearch.DSACryptographicKey.p', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='q', full_name='zsearch.DSACryptographicKey.q', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='g', full_name='zsearch.DSACryptographicKey.g', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='zsearch.DSACryptographicKey.y', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='zsearch.DSACryptographicKey.x', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=408,
)


_ECCCRYPTOGRAPHICKEY = _descriptor.Descriptor(
  name='ECCCryptographicKey',
  full_name='zsearch.ECCCryptographicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='curve', full_name='zsearch.ECCCryptographicKey.curve', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='zsearch.ECCCryptographicKey.x', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='zsearch.ECCCryptographicKey.y', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private', full_name='zsearch.ECCCryptographicKey.private', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=485,
)


_CRYPTOGRAPHICKEY = _descriptor.Descriptor(
  name='CryptographicKey',
  full_name='zsearch.CryptographicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='zsearch.CryptographicKey.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rsa', full_name='zsearch.CryptographicKey.rsa', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dsa', full_name='zsearch.CryptographicKey.dsa', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ecc', full_name='zsearch.CryptographicKey.ecc', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='broken', full_name='zsearch.CryptographicKey.broken', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='zsearch.CryptographicKey.common', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debian', full_name='zsearch.CryptographicKey.debian', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CRYPTOGRAPHICKEY_KEYTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='key_oneof', full_name='zsearch.CryptographicKey.key_oneof',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=488,
  serialized_end=816,
)


_ANONYMOUSRECORD = _descriptor.Descriptor(
  name='AnonymousRecord',
  full_name='zsearch.AnonymousRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.AnonymousRecord.sha256fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='zsearch.AnonymousRecord.timestamp', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scan_id', full_name='zsearch.AnonymousRecord.scan_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exported', full_name='zsearch.AnonymousRecord.exported', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userdata', full_name='zsearch.AnonymousRecord.userdata', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='zsearch.AnonymousRecord.data', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raw_data', full_name='zsearch.AnonymousRecord.raw_data', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certificate', full_name='zsearch.AnonymousRecord.certificate', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.AnonymousRecord.key', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='as', full_name='zsearch.AnonymousRecord.as', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='zsearch.AnonymousRecord.metadata', index=10,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='zsearch.AnonymousRecord.tags', index=11,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_data', full_name='zsearch.AnonymousRecord.oneof_data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=819,
  serialized_end=1169,
)


_ANONYMOUSDELTA = _descriptor.Descriptor(
  name='AnonymousDelta',
  full_name='zsearch.AnonymousDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='delta_type', full_name='zsearch.AnonymousDelta.delta_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delta_scope', full_name='zsearch.AnonymousDelta.delta_scope', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='record', full_name='zsearch.AnonymousDelta.record', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ANONYMOUSDELTA_DELTATYPE,
    _ANONYMOUSDELTA_DELTASCOPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1172,
  serialized_end=1490,
)

_CRYPTOGRAPHICKEY.fields_by_name['type'].enum_type = _CRYPTOGRAPHICKEY_KEYTYPE
_CRYPTOGRAPHICKEY.fields_by_name['rsa'].message_type = _RSACRYPTOGRAPHICKEY
_CRYPTOGRAPHICKEY.fields_by_name['dsa'].message_type = _DSACRYPTOGRAPHICKEY
_CRYPTOGRAPHICKEY.fields_by_name['ecc'].message_type = _ECCCRYPTOGRAPHICKEY
_CRYPTOGRAPHICKEY_KEYTYPE.containing_type = _CRYPTOGRAPHICKEY
_CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof'].fields.append(
  _CRYPTOGRAPHICKEY.fields_by_name['rsa'])
_CRYPTOGRAPHICKEY.fields_by_name['rsa'].containing_oneof = _CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof']
_CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof'].fields.append(
  _CRYPTOGRAPHICKEY.fields_by_name['dsa'])
_CRYPTOGRAPHICKEY.fields_by_name['dsa'].containing_oneof = _CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof']
_CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof'].fields.append(
  _CRYPTOGRAPHICKEY.fields_by_name['ecc'])
_CRYPTOGRAPHICKEY.fields_by_name['ecc'].containing_oneof = _CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof']
_ANONYMOUSRECORD.fields_by_name['userdata'].message_type = zsearch__definitions_dot_common__pb2._USERDATAATOM
_ANONYMOUSRECORD.fields_by_name['certificate'].message_type = _CERTIFICATE
_ANONYMOUSRECORD.fields_by_name['key'].message_type = _CRYPTOGRAPHICKEY
_ANONYMOUSRECORD.fields_by_name['as'].message_type = zsearch__definitions_dot_common__pb2._ASATOM
_ANONYMOUSRECORD.fields_by_name['metadata'].message_type = zsearch__definitions_dot_common__pb2._METADATUM
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['data'])
_ANONYMOUSRECORD.fields_by_name['data'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['raw_data'])
_ANONYMOUSRECORD.fields_by_name['raw_data'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['certificate'])
_ANONYMOUSRECORD.fields_by_name['certificate'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['key'])
_ANONYMOUSRECORD.fields_by_name['key'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['as'])
_ANONYMOUSRECORD.fields_by_name['as'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSDELTA.fields_by_name['delta_type'].enum_type = _ANONYMOUSDELTA_DELTATYPE
_ANONYMOUSDELTA.fields_by_name['delta_scope'].enum_type = _ANONYMOUSDELTA_DELTASCOPE
_ANONYMOUSDELTA.fields_by_name['record'].message_type = _ANONYMOUSRECORD
_ANONYMOUSDELTA_DELTATYPE.containing_type = _ANONYMOUSDELTA
_ANONYMOUSDELTA_DELTASCOPE.containing_type = _ANONYMOUSDELTA
DESCRIPTOR.message_types_by_name['Certificate'] = _CERTIFICATE
DESCRIPTOR.message_types_by_name['RSACryptographicKey'] = _RSACRYPTOGRAPHICKEY
DESCRIPTOR.message_types_by_name['DSACryptographicKey'] = _DSACRYPTOGRAPHICKEY
DESCRIPTOR.message_types_by_name['ECCCryptographicKey'] = _ECCCRYPTOGRAPHICKEY
DESCRIPTOR.message_types_by_name['CryptographicKey'] = _CRYPTOGRAPHICKEY
DESCRIPTOR.message_types_by_name['AnonymousRecord'] = _ANONYMOUSRECORD
DESCRIPTOR.message_types_by_name['AnonymousDelta'] = _ANONYMOUSDELTA

Certificate = _reflection.GeneratedProtocolMessageType('Certificate', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATE,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Certificate)
  ))
_sym_db.RegisterMessage(Certificate)

RSACryptographicKey = _reflection.GeneratedProtocolMessageType('RSACryptographicKey', (_message.Message,), dict(
  DESCRIPTOR = _RSACRYPTOGRAPHICKEY,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.RSACryptographicKey)
  ))
_sym_db.RegisterMessage(RSACryptographicKey)

DSACryptographicKey = _reflection.GeneratedProtocolMessageType('DSACryptographicKey', (_message.Message,), dict(
  DESCRIPTOR = _DSACRYPTOGRAPHICKEY,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.DSACryptographicKey)
  ))
_sym_db.RegisterMessage(DSACryptographicKey)

ECCCryptographicKey = _reflection.GeneratedProtocolMessageType('ECCCryptographicKey', (_message.Message,), dict(
  DESCRIPTOR = _ECCCRYPTOGRAPHICKEY,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.ECCCryptographicKey)
  ))
_sym_db.RegisterMessage(ECCCryptographicKey)

CryptographicKey = _reflection.GeneratedProtocolMessageType('CryptographicKey', (_message.Message,), dict(
  DESCRIPTOR = _CRYPTOGRAPHICKEY,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CryptographicKey)
  ))
_sym_db.RegisterMessage(CryptographicKey)

AnonymousRecord = _reflection.GeneratedProtocolMessageType('AnonymousRecord', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSRECORD,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousRecord)
  ))
_sym_db.RegisterMessage(AnonymousRecord)

AnonymousDelta = _reflection.GeneratedProtocolMessageType('AnonymousDelta', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSDELTA,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousDelta)
  ))
_sym_db.RegisterMessage(AnonymousDelta)


import abc
from grpc.early_adopter import implementations
from grpc.framework.alpha import utilities
# @@protoc_insertion_point(module_scope)



import zdb
import itertools
from zsearch_definitions import hoststore_pb2, common_pb2
import time
import unittest
import socket

import testcase


class DeltaTest(testcase.ZDBTestCase):

    TIMEOUT = 3

    def setUp(self):
        super(DeltaTest, self).setUp()
        self.service = self.query_grpc.service

    def test_new_hosts(self):
        start_ip = 0x01020304
        stop_ip = start_ip + 10
        records = list(zdb.iter_ipv4_record(
                start_ip, 443, 3, 2, ip_stop=stop_ip
        ))
        deltas = list()
        for record in records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, hoststore_pb2.Delta.DT_UPDATE)
            self.assertEqual(delta.delta_scope, hoststore_pb2.Delta.SCOPE_HOST)
            self.assertDeltaMatchesRecord(delta, record)
            self.assertDeltaHasMergedTagsAndMetadata(delta, [record])


    def test_identical_hosts(self):
        start_ip = 0x8dd47d89
        stop_ip = start_ip + 100
        records = list(zdb.iter_ipv4_record(
                start_ip, 80, 5, 4, ip_stop=stop_ip
        ))
        deltas = list()
        for record in records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
        for record in records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertEqual(delta.delta_type, hoststore_pb2.Delta.DT_UPDATE)
            self.assertEqual(delta.delta_scope, hoststore_pb2.Delta.SCOPE_NO_CHANGE)

    def test_metadata_tags_merge_host(self):
        start_ip = 0x8dd47d89
        stop_ip = start_ip + 100
        records = list(zdb.iter_ipv4_record(
                start_ip, 80, 5, 4, ip_stop=stop_ip
        ))
        deltas = list()
        for record in records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
        m = {
            "another_key": "another_value",
            "zed_key": "zed_value",
            "new_key": "new_value",
            "key": "not the original value",
        }
        metadata_list = itertools.cycle([m])
        atoms = zdb.iter_protocol_atom(metadata_list=metadata_list)
        more_records = list(zdb.iter_ipv4_record(
                start_ip, 443, 8, 6, ip_stop=stop_ip
        ))
        for record, new_record in itertools.izip(records, more_records):
            delta = self.service.PutHostIPv4Record(new_record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertDeltaMatchesRecord(delta, new_record)
            self.assertDeltaHasMergedTagsAndMetadata(delta, [record, new_record])

    def test_overwrite_subprotocol(self):
        start_ip = 0x5601afb6
        stop_ip = start_ip + 10
        records = list(zdb.iter_ipv4_record(
            start_ip, 80, 5, 4, ip_stop=stop_ip
        ))
        original_atoms = [record.atom for record in records]
        for record in records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
        new_atoms = [hoststore_pb2.ProtocolAtom(
                data=atom.data,
                tags=["new_tag"],
                metadata=[common_pb2.Metadatum(
                        key="new_metdatum_key", value="value")
                ],
        ) for atom in original_atoms]
        new_records = list(zdb.iter_ipv4_record(
            start_ip, 80, 5, 4, ip_stop=stop_ip, atom_list=new_atoms,
        ))
        for record in new_records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, hoststore_pb2.Delta.DT_UPDATE)
            self.assertEqual(delta.delta_scope, hoststore_pb2.Delta.SCOPE_SUBPROTOCOL)
            self.assertDeltaHasMergedTagsAndMetadata(delta, [record])

    def test_metadata_tags_merge_protocol(self):
        start_ip = 0x8dd47d89
        stop_ip = start_ip + 5
        first_subproto = 3
        second_subproto = 4
        first_records = list(zdb.iter_ipv4_record(
                start_ip, 443, 5, first_subproto, ip_stop=stop_ip
        ))
        first_atoms = [record.atom for record in first_records]
        for record in first_records:
            delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, hoststore_pb2.Delta.DT_UPDATE)
            self.assertEqual(delta.delta_scope, hoststore_pb2.Delta.SCOPE_HOST)

        new_atoms = [hoststore_pb2.ProtocolAtom(
                data=atom.data,
                tags=["another_tag"],
                metadata=[common_pb2.Metadatum(
                        key="key",
                        value="new_value")
                ],
        ) for atom in first_atoms]
        second_records = list(zdb.iter_ipv4_record(
                start_ip, 443, 5, second_subproto, ip_stop=stop_ip
        ))
        for first, second in itertools.izip(first_records, second_records):
            delta = self.service.PutHostIPv4Record(second, self.TIMEOUT)
            self.assertIsNotNone(delta)
            self.assertEqual(delta.delta_type, hoststore_pb2.Delta.DT_UPDATE)
            self.assertEqual(delta.delta_scope, hoststore_pb2.Delta.SCOPE_SUBPROTOCOL)
            self.assertDeltaHasMergedTagsAndMetadata(delta, [first, second])

        def test_metadata_tags_merge_port(self):
            first_proto = 5
            second_proto = 6
            first_subproto = 4
            second_subproto = 12
            tags = ["a", "b"]
            metadata = [
                common_pb2.Metadatum(key="k1", value="v1"),
                common_pb2.Metadataum(key="k2", value="v2"),
            ]
            first_atoms = zdb.iter_protocol_atom(
                tags_list=itertools.cycle([tags]),
                metadata_list=itertools.cycle([metadata])
            )
            start_ip = 0x18af03d8
            stop_ip = start_ip + 10*5
            first_records = list(zdb.iter_ipv4_record(
                    start_ip, 443, first_proto, first_subproto, ip_stop=stop_ip,
                    ip_step=5, atom_list=first_atoms
            ))
            for record in first_records:
                delta = self.service.PutHostIPv4Record(record, self.TIMEOUT)
                self.assertIsNotNone(delta)
            second_tags = ["b", "c"]
            second_metadata = [
                common_pb2.Metadataum(key="k2", value="v3"),
                common_pb2.Metadataum(key="k3", value="v3"),
            ]
            second_atoms = zdb.iter_protocol_atom(
                tags_list=itertools.cycle([second_tags]),
                metadata_list=itertools.cycle([second_metadata])
            )
            second_records = list(zdb.iter_ipv4_record(
                    start_ip, 443, second_proto, second_subproto, ip_stop=stop_ip,
                    ip_step=5, atom_list=second_atoms
            ))
            for first, second in itertools.izip(first_record, second_records):
                delta = self.service.PutHostIPv4Record(second, self.TIMEOUT)
                self.assertIsNotNone(delta)
                self.assertEqual(delta.delta_type, hoststore_pb2.Delta.DT_UPDATE)
                self.assertEqual(delta.delta_scope, hoststore_pb2.Delta.SCOPE_PROTOCOL)
                self.assertDeltaHasMergedTagsAndMetadata(delta, [first, second])

if __name__ == "__main__":
    unittest.main()



import os.path
import sys

from zsearch_definitions import search_pb2
from zsearch_definitions import rpc_pb2

class AdminService(object):
    TIMEOUT = 600 # second
    HOST = "localhost"
    PORT = 8080

    VALID_DATASTORES = [
        "IPV4",
        "DOMAIN",
        "CERTIFICATE",
        "KEY"
    ]
    
    def __init__(self, host=None, port=None):
        host = host or self.HOST
        port = port or self.PORT
        self._service = search_pb2.early_adopter_create_AdminService_stub(host, port).__enter__()

    def shutdown(self):
        return self._service.Shutdown(rpc_pb2.Command(), self.TIMEOUT)

    def status(self):
        return self._service.Status(rpc_pb2.Command(), self.TIMEOUT)

    def statistics(self, datastore):
        ds = rpc_pb2.Command.Datastore.Value(datastore)
        return self._service.Statistics(rpc_pb2.Command(datastore=ds), self.TIMEOUT)

    def dump_certificates(self, path, incremental=False, max_records=0):
        return self._service.DumpCertificatesToJSON(rpc_pb2.Command(filepath=path, 
                incremental_dump=incremental, max_records=max_records), 3600)

    def dump_ipv4(self, path, max_records=0):
        return self._service.DumpIPv4ToJSON(rpc_pb2.Command(filepath=path,
                max_records=max_records), 3600)

    def dump_domain(self, path, max_records=0):
        return self._service.DumpDomainToJSON(rpc_pb2.Command(filepath=path, 
                max_records=max_records), 3600)

    def prune(self, datastore, scan_ids):
        if datastore not in self.VALID_DATSTORES:
            sys.stderr.write("ERROR: invalid datastore. Valid datastores: %s\n" % self.VALID_DATASTORES)
        pb_scan_ids = []
        for (port, proto, subproto, min_id) in scan_ids:
            ak = rpc_pb2.AnonymousKey(port=port,proto=proto,subproto=subproto)
            pb_scan_ids.append(rpc_pb2.MinScanId(key=ak, min_scan_id=min_id))
        ds = rpc_pb2.Command.Value(datastore)
        c = rpc_pb2.Command(min_scan_ids=pb_scan_ids, datastore=ds)
        return self._service.Status(c, self.TIMEOUT)

    def __del__(self):
        if self._service:
            self._service.__exit__(None, None, None)





# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zsearch_definitions/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='zsearch_definitions/common.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n zsearch_definitions/common.proto\x12\x07zsearch\"\'\n\tMetadatum\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xc1\x01\n\x0cUserdataAtom\x12\x15\n\rprivate_notes\x18\x01 \x01(\t\x12\x14\n\x0cpublic_notes\x18\x02 \x01(\t\x12,\n\x10private_metadata\x18\x03 \x03(\x0b\x32\x12.zsearch.Metadatum\x12+\n\x0fpublic_metadata\x18\x04 \x03(\x0b\x32\x12.zsearch.Metadatum\x12\x14\n\x0cprivate_tags\x18\x05 \x03(\t\x12\x13\n\x0bpublic_tags\x18\x06 \x03(\t\"5\n\x06\x41SAtom\x12\x0b\n\x03\x61sn\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x04path\x18\x03 \x03(\rB\x02\x10\x01\x62\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_METADATUM = _descriptor.Descriptor(
  name='Metadatum',
  full_name='zsearch.Metadatum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.Metadatum.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='zsearch.Metadatum.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=84,
)


_USERDATAATOM = _descriptor.Descriptor(
  name='UserdataAtom',
  full_name='zsearch.UserdataAtom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='private_notes', full_name='zsearch.UserdataAtom.private_notes', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_notes', full_name='zsearch.UserdataAtom.public_notes', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private_metadata', full_name='zsearch.UserdataAtom.private_metadata', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_metadata', full_name='zsearch.UserdataAtom.public_metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private_tags', full_name='zsearch.UserdataAtom.private_tags', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_tags', full_name='zsearch.UserdataAtom.public_tags', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=280,
)


_ASATOM = _descriptor.Descriptor(
  name='ASAtom',
  full_name='zsearch.ASAtom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='asn', full_name='zsearch.ASAtom.asn', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='zsearch.ASAtom.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='path', full_name='zsearch.ASAtom.path', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=335,
)

_USERDATAATOM.fields_by_name['private_metadata'].message_type = _METADATUM
_USERDATAATOM.fields_by_name['public_metadata'].message_type = _METADATUM
DESCRIPTOR.message_types_by_name['Metadatum'] = _METADATUM
DESCRIPTOR.message_types_by_name['UserdataAtom'] = _USERDATAATOM
DESCRIPTOR.message_types_by_name['ASAtom'] = _ASATOM

Metadatum = _reflection.GeneratedProtocolMessageType('Metadatum', (_message.Message,), dict(
  DESCRIPTOR = _METADATUM,
  __module__ = 'zsearch_definitions.common_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Metadatum)
  ))
_sym_db.RegisterMessage(Metadatum)

UserdataAtom = _reflection.GeneratedProtocolMessageType('UserdataAtom', (_message.Message,), dict(
  DESCRIPTOR = _USERDATAATOM,
  __module__ = 'zsearch_definitions.common_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.UserdataAtom)
  ))
_sym_db.RegisterMessage(UserdataAtom)

ASAtom = _reflection.GeneratedProtocolMessageType('ASAtom', (_message.Message,), dict(
  DESCRIPTOR = _ASATOM,
  __module__ = 'zsearch_definitions.common_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.ASAtom)
  ))
_sym_db.RegisterMessage(ASAtom)


_ASATOM.fields_by_name['path'].has_options = True
_ASATOM.fields_by_name['path']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
import abc
from grpc.early_adopter import implementations
from grpc.framework.alpha import utilities
# @@protoc_insertion_point(module_scope)



from setuptools import setup, find_packages

setup(
    name = "zsearch-definitions",
    description = "Egg version of files that can be used for interacting with zdb through python",
    version = "0.0.4",
    license = "Apache License, Version 2.0",
    author = "Zakir Durumeric",
    author_email = "zakird@gmail.com",
    maintainer = "Zakir Durumeric",
    maintainer_email = "zakird@gmail.com",
    keywords = "python json zsearch",
    zip_safe = False,
    install_requires = [
        "zschema"
    ],
    packages = [
        "zsearch_definitions",
    ]
)




# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zsearch_definitions/hoststore.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zsearch_definitions import common_pb2 as zsearch__definitions_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='zsearch_definitions/hoststore.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n#zsearch_definitions/hoststore.proto\x12\x07zsearch\x1a zsearch_definitions/common.proto\"\x0b\n\tWHOISAtom\"\xf1\x01\n\x0cLocationAtom\x12\x11\n\tcontinent\x18\x01 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12\x0c\n\x04\x63ity\x18\x04 \x01(\t\x12\x13\n\x0bpostal_code\x18\x05 \x01(\t\x12\x10\n\x08timezone\x18\x06 \x01(\t\x12\x10\n\x08province\x18\x07 \x01(\t\x12\x10\n\x08latitude\x18\x08 \x01(\x01\x12\x11\n\tlongitude\x18\t \x01(\x01\x12\x1a\n\x12registered_country\x18\n \x01(\t\x12\x1f\n\x17registered_country_code\x18\x0b \x01(\t\"P\n\x0cProtocolAtom\x12$\n\x08metadata\x18\x01 \x03(\x0b\x32\x12.zsearch.Metadatum\x12\x0c\n\x04tags\x18\x02 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"\x1d\n\rAlexaRankAtom\x12\x0c\n\x04rank\x18\x01 \x01(\r\"C\n\x0c\x41nonymousKey\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x10\n\x08protocol\x18\x02 \x01(\r\x12\x13\n\x0bsubprotocol\x18\x03 \x01(\r\"\xfd\x03\n\x06Record\x12\n\n\x02ip\x18\x01 \x01(\x07\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x10\n\x08protocol\x18\x03 \x01(\r\x12\x13\n\x0bsubprotocol\x18\x04 \x01(\r\x12\x0e\n\x06\x64omain\x18\x05 \x01(\t\x12\x11\n\ttimestamp\x18\x06 \x01(\x07\x12\x0e\n\x06scanid\x18\x07 \x01(\r\x12\x10\n\x08sha256fp\x18\x08 \x01(\x0c\x12\x1d\n\x15\x66irst_seen_at_scan_id\x18\t \x01(\r\x12\x1c\n\x14last_seen_at_scan_id\x18\n \x01(\r\x12%\n\x04\x61tom\x18\x0b \x01(\x0b\x32\x15.zsearch.ProtocolAtomH\x00\x12\x31\n\x10private_location\x18\x0c \x01(\x0b\x32\x15.zsearch.LocationAtomH\x00\x12\x1d\n\x02\x61s\x18\r \x01(\x0b\x32\x0f.zsearch.ASAtomH\x00\x12#\n\x05whois\x18\x0e \x01(\x0b\x32\x12.zsearch.WHOISAtomH\x00\x12)\n\x08userdata\x18\x0f \x01(\x0b\x32\x15.zsearch.UserdataAtomH\x00\x12\'\n\x05\x61lexa\x18\x10 \x01(\x0b\x32\x16.zsearch.AlexaRankAtomH\x00\x12\x30\n\x0fpublic_location\x18\x11 \x01(\x0b\x32\x15.zsearch.LocationAtomH\x00\x42\x0c\n\ndata_oneof\"\xbb\x05\n\x05\x44\x65lta\x12\n\n\x02ip\x18\x01 \x01(\x07\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x10\n\x08protocol\x18\x03 \x01(\r\x12\x13\n\x0bsubprotocol\x18\x04 \x01(\r\x12\x0e\n\x06\x64omain\x18\x05 \x01(\t\x12\x11\n\ttimestamp\x18\x06 \x01(\x07\x12\x0e\n\x06scanid\x18\x07 \x01(\r\x12#\n\x04\x64\x61ta\x18\x08 \x01(\x0b\x32\x15.zsearch.ProtocolAtom\x12.\n\x0fpublic_location\x18\t \x01(\x0b\x32\x15.zsearch.LocationAtom\x12/\n\x10private_location\x18\n \x01(\x0b\x32\x15.zsearch.LocationAtom\x12\x1b\n\x02\x61s\x18\x0b \x01(\x0b\x32\x0f.zsearch.ASAtom\x12!\n\x05whois\x18\x0c \x01(\x0b\x32\x12.zsearch.WHOISAtom\x12\'\n\x08userdata\x18\r \x01(\x0b\x32\x15.zsearch.UserdataAtom\x12$\n\x08metadata\x18\x0e \x03(\x0b\x32\x12.zsearch.Metadatum\x12\x0c\n\x04tags\x18\x0f \x03(\t\x12,\n\ndelta_type\x18\x10 \x01(\x0e\x32\x18.zsearch.Delta.DeltaType\x12.\n\x0b\x64\x65lta_scope\x18\x11 \x01(\x0e\x32\x19.zsearch.Delta.DeltaScope\":\n\tDeltaType\x12\x0f\n\x0b\x44T_RESERVED\x10\x00\x12\r\n\tDT_UPDATE\x10\x01\x12\r\n\tDT_DELETE\x10\x02\"\x80\x01\n\nDeltaScope\x12\x12\n\x0eSCOPE_RESERVED\x10\x00\x12\x13\n\x0fSCOPE_NO_CHANGE\x10\x01\x12\x0e\n\nSCOPE_HOST\x10\x02\x12\x0e\n\nSCOPE_PORT\x10\x03\x12\x12\n\x0eSCOPE_PROTOCOL\x10\x04\x12\x15\n\x11SCOPE_SUBPROTOCOL\x10\x05\x62\x06proto3')
  ,
  dependencies=[zsearch__definitions_dot_common__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_DELTA_DELTATYPE = _descriptor.EnumDescriptor(
  name='DeltaType',
  full_name='zsearch.Delta.DeltaType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DT_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DT_UPDATE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DT_DELETE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1544,
  serialized_end=1602,
)
_sym_db.RegisterEnumDescriptor(_DELTA_DELTATYPE)

_DELTA_DELTASCOPE = _descriptor.EnumDescriptor(
  name='DeltaScope',
  full_name='zsearch.Delta.DeltaScope',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCOPE_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_NO_CHANGE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_HOST', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_PORT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_PROTOCOL', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_SUBPROTOCOL', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1605,
  serialized_end=1733,
)
_sym_db.RegisterEnumDescriptor(_DELTA_DELTASCOPE)


_WHOISATOM = _descriptor.Descriptor(
  name='WHOISAtom',
  full_name='zsearch.WHOISAtom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=93,
)


_LOCATIONATOM = _descriptor.Descriptor(
  name='LocationAtom',
  full_name='zsearch.LocationAtom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='continent', full_name='zsearch.LocationAtom.continent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country', full_name='zsearch.LocationAtom.country', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='zsearch.LocationAtom.country_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='city', full_name='zsearch.LocationAtom.city', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='postal_code', full_name='zsearch.LocationAtom.postal_code', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='zsearch.LocationAtom.timezone', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='province', full_name='zsearch.LocationAtom.province', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='zsearch.LocationAtom.latitude', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='zsearch.LocationAtom.longitude', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='registered_country', full_name='zsearch.LocationAtom.registered_country', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='registered_country_code', full_name='zsearch.LocationAtom.registered_country_code', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=337,
)


_PROTOCOLATOM = _descriptor.Descriptor(
  name='ProtocolAtom',
  full_name='zsearch.ProtocolAtom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='zsearch.ProtocolAtom.metadata', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='zsearch.ProtocolAtom.tags', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='zsearch.ProtocolAtom.data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=419,
)


_ALEXARANKATOM = _descriptor.Descriptor(
  name='AlexaRankAtom',
  full_name='zsearch.AlexaRankAtom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rank', full_name='zsearch.AlexaRankAtom.rank', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=450,
)


_ANONYMOUSKEY = _descriptor.Descriptor(
  name='AnonymousKey',
  full_name='zsearch.AnonymousKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='zsearch.AnonymousKey.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='zsearch.AnonymousKey.protocol', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subprotocol', full_name='zsearch.AnonymousKey.subprotocol', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=452,
  serialized_end=519,
)


_RECORD = _descriptor.Descriptor(
  name='Record',
  full_name='zsearch.Record',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='zsearch.Record.ip', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='zsearch.Record.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='zsearch.Record.protocol', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subprotocol', full_name='zsearch.Record.subprotocol', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='domain', full_name='zsearch.Record.domain', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='zsearch.Record.timestamp', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scanid', full_name='zsearch.Record.scanid', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.Record.sha256fp', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_seen_at_scan_id', full_name='zsearch.Record.first_seen_at_scan_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_seen_at_scan_id', full_name='zsearch.Record.last_seen_at_scan_id', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='atom', full_name='zsearch.Record.atom', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private_location', full_name='zsearch.Record.private_location', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='as', full_name='zsearch.Record.as', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='whois', full_name='zsearch.Record.whois', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userdata', full_name='zsearch.Record.userdata', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alexa', full_name='zsearch.Record.alexa', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_location', full_name='zsearch.Record.public_location', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data_oneof', full_name='zsearch.Record.data_oneof',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=522,
  serialized_end=1031,
)


_DELTA = _descriptor.Descriptor(
  name='Delta',
  full_name='zsearch.Delta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='zsearch.Delta.ip', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='zsearch.Delta.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='zsearch.Delta.protocol', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subprotocol', full_name='zsearch.Delta.subprotocol', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='domain', full_name='zsearch.Delta.domain', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='zsearch.Delta.timestamp', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scanid', full_name='zsearch.Delta.scanid', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='zsearch.Delta.data', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_location', full_name='zsearch.Delta.public_location', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private_location', full_name='zsearch.Delta.private_location', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='as', full_name='zsearch.Delta.as', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='whois', full_name='zsearch.Delta.whois', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userdata', full_name='zsearch.Delta.userdata', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='zsearch.Delta.metadata', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='zsearch.Delta.tags', index=14,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delta_type', full_name='zsearch.Delta.delta_type', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delta_scope', full_name='zsearch.Delta.delta_scope', index=16,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DELTA_DELTATYPE,
    _DELTA_DELTASCOPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1733,
)

_PROTOCOLATOM.fields_by_name['metadata'].message_type = zsearch__definitions_dot_common__pb2._METADATUM
_RECORD.fields_by_name['atom'].message_type = _PROTOCOLATOM
_RECORD.fields_by_name['private_location'].message_type = _LOCATIONATOM
_RECORD.fields_by_name['as'].message_type = zsearch__definitions_dot_common__pb2._ASATOM
_RECORD.fields_by_name['whois'].message_type = _WHOISATOM
_RECORD.fields_by_name['userdata'].message_type = zsearch__definitions_dot_common__pb2._USERDATAATOM
_RECORD.fields_by_name['alexa'].message_type = _ALEXARANKATOM
_RECORD.fields_by_name['public_location'].message_type = _LOCATIONATOM
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['atom'])
_RECORD.fields_by_name['atom'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['private_location'])
_RECORD.fields_by_name['private_location'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['as'])
_RECORD.fields_by_name['as'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['whois'])
_RECORD.fields_by_name['whois'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['userdata'])
_RECORD.fields_by_name['userdata'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['alexa'])
_RECORD.fields_by_name['alexa'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_RECORD.oneofs_by_name['data_oneof'].fields.append(
  _RECORD.fields_by_name['public_location'])
_RECORD.fields_by_name['public_location'].containing_oneof = _RECORD.oneofs_by_name['data_oneof']
_DELTA.fields_by_name['data'].message_type = _PROTOCOLATOM
_DELTA.fields_by_name['public_location'].message_type = _LOCATIONATOM
_DELTA.fields_by_name['private_location'].message_type = _LOCATIONATOM
_DELTA.fields_by_name['as'].message_type = zsearch__definitions_dot_common__pb2._ASATOM
_DELTA.fields_by_name['whois'].message_type = _WHOISATOM
_DELTA.fields_by_name['userdata'].message_type = zsearch__definitions_dot_common__pb2._USERDATAATOM
_DELTA.fields_by_name['metadata'].message_type = zsearch__definitions_dot_common__pb2._METADATUM
_DELTA.fields_by_name['delta_type'].enum_type = _DELTA_DELTATYPE
_DELTA.fields_by_name['delta_scope'].enum_type = _DELTA_DELTASCOPE
_DELTA_DELTATYPE.containing_type = _DELTA
_DELTA_DELTASCOPE.containing_type = _DELTA
DESCRIPTOR.message_types_by_name['WHOISAtom'] = _WHOISATOM
DESCRIPTOR.message_types_by_name['LocationAtom'] = _LOCATIONATOM
DESCRIPTOR.message_types_by_name['ProtocolAtom'] = _PROTOCOLATOM
DESCRIPTOR.message_types_by_name['AlexaRankAtom'] = _ALEXARANKATOM
DESCRIPTOR.message_types_by_name['AnonymousKey'] = _ANONYMOUSKEY
DESCRIPTOR.message_types_by_name['Record'] = _RECORD
DESCRIPTOR.message_types_by_name['Delta'] = _DELTA

WHOISAtom = _reflection.GeneratedProtocolMessageType('WHOISAtom', (_message.Message,), dict(
  DESCRIPTOR = _WHOISATOM,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.WHOISAtom)
  ))
_sym_db.RegisterMessage(WHOISAtom)

LocationAtom = _reflection.GeneratedProtocolMessageType('LocationAtom', (_message.Message,), dict(
  DESCRIPTOR = _LOCATIONATOM,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.LocationAtom)
  ))
_sym_db.RegisterMessage(LocationAtom)

ProtocolAtom = _reflection.GeneratedProtocolMessageType('ProtocolAtom', (_message.Message,), dict(
  DESCRIPTOR = _PROTOCOLATOM,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.ProtocolAtom)
  ))
_sym_db.RegisterMessage(ProtocolAtom)

AlexaRankAtom = _reflection.GeneratedProtocolMessageType('AlexaRankAtom', (_message.Message,), dict(
  DESCRIPTOR = _ALEXARANKATOM,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AlexaRankAtom)
  ))
_sym_db.RegisterMessage(AlexaRankAtom)

AnonymousKey = _reflection.GeneratedProtocolMessageType('AnonymousKey', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSKEY,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousKey)
  ))
_sym_db.RegisterMessage(AnonymousKey)

Record = _reflection.GeneratedProtocolMessageType('Record', (_message.Message,), dict(
  DESCRIPTOR = _RECORD,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Record)
  ))
_sym_db.RegisterMessage(Record)

Delta = _reflection.GeneratedProtocolMessageType('Delta', (_message.Message,), dict(
  DESCRIPTOR = _DELTA,
  __module__ = 'zsearch_definitions.hoststore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Delta)
  ))
_sym_db.RegisterMessage(Delta)


import abc
from grpc.early_adopter import implementations
from grpc.framework.alpha import utilities
# @@protoc_insertion_point(module_scope)
